@@ -175,10 +175,12 @@ fn main() {
             let result = rt.block_on(client.get_dioceses(
                   Some(serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")),
                   None,
+                  Some("province_name_example".to_string()),
                   Some("name_example".to_string()),
                   Some("location_name_example".to_string()),
                   Some("location_address_example".to_string()),
                   Some("location_email_example".to_string()),
+                  Some("person_in_charge_example".to_string()),
                   Some(&Vec::new()),
                   Some(56),
                   Some(56)
@@ -217,6 +219,11 @@ fn main() {
         Some("GetInstitutes") => {
             let result = rt.block_on(client.get_institutes(
                   Some("name_example".to_string()),
+                  Some("location_name_example".to_string()),
+                  Some("location_address_example".to_string()),
+                  Some("location_email_example".to_string()),
+                  Some("person_in_charge_example".to_string()),
+                  Some(&Vec::new()),
                   Some(56),
                   Some(56)
             ));
