@@ -226,17 +226,19 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         &self,
         province_id: Option<uuid::Uuid>,
         province_code: Option<models::Code>,
+        province_name: Option<String>,
         name: Option<String>,
         location_name: Option<String>,
         location_address: Option<String>,
         location_email: Option<String>,
+        person_in_charge: Option<String>,
         sorts: Option<&Vec<models::DioceseSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         context: &C) -> Result<GetDiocesesResponse, ApiError>
     {
         let context = context.clone();
-        info!("get_dioceses({:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", province_id, province_code, name, location_name, location_address, location_email, sorts, offset, count, context.get().0.clone());
+        info!("get_dioceses({:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", province_id, province_code, province_name, name, location_name, location_address, location_email, person_in_charge, sorts, offset, count, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
@@ -289,12 +291,17 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
     async fn get_institutes(
         &self,
         name: Option<String>,
+        location_name: Option<String>,
+        location_address: Option<String>,
+        location_email: Option<String>,
+        person_in_charge: Option<String>,
+        sorts: Option<&Vec<models::InstituteSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         context: &C) -> Result<GetInstitutesResponse, ApiError>
     {
         let context = context.clone();
-        info!("get_institutes({:?}, {:?}, {:?}) - X-Span-ID: {:?}", name, offset, count, context.get().0.clone());
+        info!("get_institutes({:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", name, location_name, location_address, location_email, person_in_charge, sorts, offset, count, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
