@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.9.0";
+pub const API_VERSION: &'static str = "0.11.0";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -421,10 +421,12 @@ pub trait Api<C: Send + Sync> {
         &self,
         province_id: Option<uuid::Uuid>,
         province_code: Option<models::Code>,
+        province_name: Option<String>,
         name: Option<String>,
         location_name: Option<String>,
         location_address: Option<String>,
         location_email: Option<String>,
+        person_in_charge: Option<String>,
         sorts: Option<&Vec<models::DioceseSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
@@ -459,6 +461,11 @@ pub trait Api<C: Send + Sync> {
     async fn get_institutes(
         &self,
         name: Option<String>,
+        location_name: Option<String>,
+        location_address: Option<String>,
+        location_email: Option<String>,
+        person_in_charge: Option<String>,
+        sorts: Option<&Vec<models::InstituteSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         context: &C) -> Result<GetInstitutesResponse, ApiError>;
@@ -606,10 +613,12 @@ pub trait ApiNoContext<C: Send + Sync> {
         &self,
         province_id: Option<uuid::Uuid>,
         province_code: Option<models::Code>,
+        province_name: Option<String>,
         name: Option<String>,
         location_name: Option<String>,
         location_address: Option<String>,
         location_email: Option<String>,
+        person_in_charge: Option<String>,
         sorts: Option<&Vec<models::DioceseSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
@@ -644,6 +653,11 @@ pub trait ApiNoContext<C: Send + Sync> {
     async fn get_institutes(
         &self,
         name: Option<String>,
+        location_name: Option<String>,
+        location_address: Option<String>,
+        location_email: Option<String>,
+        person_in_charge: Option<String>,
+        sorts: Option<&Vec<models::InstituteSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         ) -> Result<GetInstitutesResponse, ApiError>;
@@ -838,17 +852,19 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         &self,
         province_id: Option<uuid::Uuid>,
         province_code: Option<models::Code>,
+        province_name: Option<String>,
         name: Option<String>,
         location_name: Option<String>,
         location_address: Option<String>,
         location_email: Option<String>,
+        person_in_charge: Option<String>,
         sorts: Option<&Vec<models::DioceseSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         ) -> Result<GetDiocesesResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().get_dioceses(province_id, province_code, name, location_name, location_address, location_email, sorts, offset, count, &context).await
+        self.api().get_dioceses(province_id, province_code, province_name, name, location_name, location_address, location_email, person_in_charge, sorts, offset, count, &context).await
     }
 
     /// Update an existing diocese
@@ -896,12 +912,17 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     async fn get_institutes(
         &self,
         name: Option<String>,
+        location_name: Option<String>,
+        location_address: Option<String>,
+        location_email: Option<String>,
+        person_in_charge: Option<String>,
+        sorts: Option<&Vec<models::InstituteSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         ) -> Result<GetInstitutesResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().get_institutes(name, offset, count, &context).await
+        self.api().get_institutes(name, location_name, location_address, location_email, person_in_charge, sorts, offset, count, &context).await
     }
 
     /// Update an existing institute
